#ifndef __REMOTEICONVIEW_H__
#define __REMOTEICONVIEW_H__

#include <gui/iconview.h>
#include <util/datetime.h>
#include <gui/image.h>
#include <gui/bitmap.h>
#include <gui/stringview.h>

#include <vector>

#include "application.h"
#include "messages.h"
#include "remotenode.h"
#include "server.h"



using namespace os;


/** \brief RemotIconData Class.
 * This extends the IconData class to contain a RemoteNode object.
 */
class RemoteIconData : public IconData {
public:
	RemoteNode m_cNode; /**< RemoteNode object corresponding to this icon. */
};

/** \brief FTPRemoteView
 * This class provides functionality for request directory information from the
 * remote server and to copy items from the remote directory into the local directory.
 *
 * \todo Once this is under CVS all ifdef 0 code should be removed.
 * \todo This should be renamed so that it doesn't sound like it's unique to FTP 
 * servers only.
 */
class FTPRemoteView : public IconView
{
public:
	FTPRemoteView( const Rect& cFrame, const String& zName );
	~FTPRemoteView();
	
	void SetServer( Server* pcServer );
	Server* GetServer();
	void SetPath( const String& zPath );
	String GetPath();
	void ShowMessage( const String& zMsg );
	void HideMessage();
	
	void Update();
	void SetContents( std::vector< RemoteNode >* pacContents, bool bInitial, bool bFinal );
	

	void AttachedToWindow();
	void SetDirChangeMsg( Message* pcMsg );
	void Invoked( uint nIcon, IconData* pcData );
	void MouseUp( const Point& cPoint, uint32 nButtons, Message* pcData );

	void DragSelection( Point cStartPoint );
//	void OpenContextMenu( Point cPosition, bool bMouseOverIcon );	/* Context menu includes 'transfer', 'view', 'rename', 'delete' etc */
	
	void HandleMessage( Message* pcMessage );
	
	Image* GetNodeImage( RemoteNode* pcNode, bool bSmall );
	
private:

	/** \brief Server object that the remote view connects to.
	 * Server object provides GetChildren(), StartTransfer(), 
	 * PauseTransfer(), CancelTransfer() etc 
	 */
	Server* m_pcServer;

	/** \brief Path of current directory.
	 * This contains the absolute path from remote server root (eg /home/user ) */
	String m_zPath;
	
	/** \brief Flag for whether an update is pending or not.
	 * If true, we are waiting for the server to give a directory listing
	 */
	bool m_bUpdatePending;
	
	/** \brief Passed to ServerConnection::RequestDirListing(), so we don't get confused by late updates
	 *
	 * \note AWM: Is this necessary?
	 */
	int m_nUpdateCookie;
	
	/** \brief Sent to the target when user changes directory. */
	Message* m_pcDirChangedMsg;
	
//	StringView* m_pcStringView;		/* Used for displaying "Not connected" message, etc */	/* TODO: crashes when quitting !? */
};


#endif  /* __REMOTEICONVIEW_H__ */



