#ifndef __SETTINGS_H__
#define __SETTINGS_H__

#include <util/settings.h>

using namespace os;

/** \brief Stores the special FTPServer settings.
 * This is used to create a settings file for the FTPServer.
 *
 * \todo FTPSettings class should be renamed to TransferrerSettings because it is not FTP protocol-specific.
 */
class FTPSettings : public Settings
{
public:
	
	/** \brief Return if the connection is passive.
	 * Returns the value for the setting 'passive' or true if it isn't found.
	 */
	bool GetPassive()
	{
		return( GetBool( "passive", true ) );
	}
	
	/** \brief Set the value for passive.
	 * \param bPassive Whether or not this is a passive connection.
	 */
	status_t SetPassive( bool bPassive )
	{
		return( SetBool( "passive", bPassive ) );
	}
	
	/** \brief Return the maximum number of connections.
	 * This returns the maximum number of allowable connections or 2 by default.
	 */
	int GetMaxConnections()
	{
		return( GetInt32( "max_connections", 2 ) );
	}
	
	/** \brief Set the maximum number of connections.
	 *
	 * \param nMax The maximum number of connections to allow at one time.
	 */
	status_t SetMaxConnections( int nMax )
	{
		return( SetInt32( "max_connections", nMax ) );
	}
	
	/** \brief Return the value of the save_history option.
	 * Returns the value of the save_history option or true if it doesn't exist.
	 */
	bool GetSaveHistory()
	{
		return( GetBool( "save_history", true ) );
	}
	
	/** \brief Set the value for the save_history option.
	 * \param bSave Value to set the save_history option to.
	 */
	status_t SetSaveHistory( bool bSave )
	{
		return( SetBool( "save_history", bSave ) ); 
	}
};


#endif	/* __SETTINGS_H__ */

