#ifndef FTP_VIEW_H
#define FTP_VIEW_H

#include <gui/view.h>
#include <gui/splitter.h>

#include "remoteview.h"
#include "localview.h"
#include "address_field.h"
#include "server.h"

/** \brief Main view window container.
 * This contains the local and remote directory views and displays them.
 * It also contains the address bars for the local and remote servers.
 *
 * \todo This should be renamed to TransferrerView to reflect that it
 * works with generic views, not just FTP views.
 */
class FTPView : public os::View
{
public:
	FTPView(const os::Rect&, const os::String&);
public:
	void SetServer( Server* pcServer );
	
	void HandleMessage( Message* pcMessage );
	
	void AllAttached();
	void ReRead();
	
	os::Point GetPreferredSize(bool) const;
private:
	
	/** \brief Vertical splitter bar. */
	os::Splitter* m_pcSplitter;
	
	/** \brief Remote directory listing container view. */
	FTPRemoteView* remote;
	
	/** \brief Contains the current remote file path buttons. */
	AddressField* m_pcRemoteBar;

	/** \brief Local directory listing container view. */
	FTPLocalView* iconview;   //using this so we can use drag/drop

	/** \brief Contains the current local file path buttons. */
	AddressField* m_pcLocalBar;
};

#endif






